/// <reference types="node" />
import type { ChatCompletionMessageParam } from 'openai/resources';
import { DailyCall, DailyAdvancedConfig, DailyFactoryOptions, DailyParticipant, DailyVideoSendSettings } from '@daily-co/daily-js';
import EventEmitter from 'events';
import { Call, CreateSquadDTO, CreateAssistantDTO, AssistantOverrides, CreateWorkflowDTO } from './api';
export interface AddMessageMessage {
    type: 'add-message';
    message: ChatCompletionMessageParam;
}
export interface ControlMessages {
    type: 'control';
    control: 'mute-assistant' | 'unmute-assistant' | 'say-first-message';
    videoRecordingStartDelaySeconds?: number;
}
export interface SayMessage {
    type: 'say';
    message: string;
    endCallAfterSpoken?: boolean;
    interruptionsEnabled?: boolean;
}
type VapiClientToServerMessage = AddMessageMessage | ControlMessages | SayMessage;
type VapiEventNames = 'call-end' | 'call-start' | 'volume-level' | 'speech-start' | 'speech-end' | 'message' | 'video' | 'error' | 'daily-participant-updated';
type VapiEventListeners = {
    'call-end': () => void;
    'call-start': () => void;
    'volume-level': (volume: number) => void;
    'speech-start': () => void;
    'speech-end': () => void;
    video: (track: MediaStreamTrack) => void;
    message: (message: any) => void;
    error: (error: any) => void;
    'daily-participant-updated': (participant: DailyParticipant) => void;
};
declare class VapiEventEmitter extends EventEmitter {
    on<E extends VapiEventNames>(event: E, listener: VapiEventListeners[E]): this;
    once<E extends VapiEventNames>(event: E, listener: VapiEventListeners[E]): this;
    emit<E extends VapiEventNames>(event: E, ...args: Parameters<VapiEventListeners[E]>): boolean;
    removeListener<E extends VapiEventNames>(event: E, listener: VapiEventListeners[E]): this;
    removeAllListeners(event?: VapiEventNames): this;
}
export default class Vapi extends VapiEventEmitter {
    private started;
    private call;
    private speakingTimeout;
    private dailyCallConfig;
    private dailyCallObject;
    private hasEmittedCallEndedStatus;
    constructor(apiToken: string, apiBaseUrl?: string, dailyCallConfig?: Pick<DailyAdvancedConfig, 'avoidEval' | 'alwaysIncludeMicInPermissionPrompt'>, dailyCallObject?: Pick<DailyFactoryOptions, 'audioSource' | 'startAudioOff'>);
    private cleanup;
    private isMobileDevice;
    private sleep;
    start(assistant?: CreateAssistantDTO | string, assistantOverrides?: AssistantOverrides, squad?: CreateSquadDTO | string, workflow?: CreateWorkflowDTO | string): Promise<Call | null>;
    private onAppMessage;
    private handleRemoteParticipantsAudioLevel;
    stop(): void;
    send(message: VapiClientToServerMessage): void;
    setMuted(mute: boolean): void;
    isMuted(): boolean;
    say(message: string, endCallAfterSpoken?: boolean, interruptionsEnabled?: boolean): void;
    setInputDevicesAsync(options: Parameters<DailyCall['setInputDevicesAsync']>[0]): void;
    increaseMicLevel(gain: number): Promise<void>;
    setOutputDeviceAsync(options: Parameters<DailyCall['setOutputDeviceAsync']>[0]): void;
    getDailyCallObject(): DailyCall | null;
    startScreenSharing(displayMediaOptions?: DisplayMediaStreamOptions, screenVideoSendSettings?: DailyVideoSendSettings): void;
    stopScreenSharing(): void;
}
export {};
